@@ -5,13 +5,14 @@
     Contact ........ jimmy@advcs.org
     Home Site ...... http://www.advcs.org/
     Program ........ Address Add
-    Version ........ 1.9
+    Version ........ 2.0
     Purpose ........ Allows you to add the From address to the address book
 
 *******************************************************************************/
 
 global $address;
-include_once('../functions/addressbook.php');
+include_once(SM_PATH . 'functions/addressbook.php');
+include_once(SM_PATH . 'functions/mime.php');
 // open address book, trash errors, skip LDAP
 $address = addressbook_init(false, true);
 if ($address->localbackend == 0)
