@@ -5,7 +5,7 @@
     Contact ........ jimmy@advcs.org
     Home Site ...... http://www.advcs.org/
     Program ........ Address Add
-    Version ........ 1.9
+    Version ........ 2.0
     Purpose ........ Allows you to add the From address to the address book
 
 *******************************************************************************/
@@ -29,7 +29,7 @@ function address_add_start () {
 }
 
 function address_add_version() { 
-   return 1.9;
+   return '2.0';
 }
 
 ?>
\ No newline at end of file
